import { FocusMonitor } from '@angular/cdk/a11y';
import { BooleanInput } from '@angular/cdk/coercion';
import { ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
/** Change event object emitted by sbb angular checkboxes. */
export declare class SbbCheckboxChange<TCheckbox extends SbbCheckboxBase = SbbCheckboxBase> {
    /** The source checkbox of the event. */
    source: TCheckbox;
    /** The new `checked` value of the checkbox. */
    checked: boolean;
    constructor(
    /** The source checkbox of the event. */
    source: TCheckbox, 
    /** The new `checked` value of the checkbox. */
    checked: boolean);
}
export declare abstract class SbbCheckboxBase<TChange extends SbbCheckboxChange = SbbCheckboxChange<any>> implements ControlValueAccessor {
    protected readonly _changeDetectorRef: ChangeDetectorRef;
    private _focusMonitor;
    private _uniqueId;
    /** A unique id for the checkbox input. If none is supplied, it will be auto-generated. */
    id: string;
    /** Id for the inner input field. */
    get inputId(): string;
    /** Value contained in a checkbox field */
    value: any;
    /** Used to set the 'aria-label' attribute on the underlying input element. */
    ariaLabel: string;
    /** The 'aria-labelledby' attribute takes precedence as the element's text alternative. */
    ariaLabelledby: string;
    /** The 'aria-describedby' attribute is read after the element's label and field type. */
    ariaDescribedby: string;
    /** The tabindex of the checkbox */
    tabIndex: number;
    /** Whether the checkbox is required. */
    get required(): boolean;
    set required(value: boolean);
    private _required;
    /** Name value will be applied to the input element if present */
    name: string | null;
    /** Whether the checkbox is checked. */
    get checked(): any;
    set checked(value: any);
    private _checked;
    /** Whether the checkbox is disabled. */
    get disabled(): any;
    set disabled(value: any);
    private _disabled;
    /** Event emitted when the checkbox's `checked` value changes. */
    readonly change: EventEmitter<TChange>;
    /** @docs-private */
    _inputElement: ElementRef<HTMLInputElement>;
    /** Property that describes the status change of a checkbox field */
    private _onChange;
    /** Property that describes an updating of checkbox */
    private _onTouched;
    constructor(_changeDetectorRef: ChangeDetectorRef, _focusMonitor: FocusMonitor, elementRef: ElementRef<HTMLElement>, tabIndex: string, type?: string);
    /** Sets the value in input in the checkbox field */
    writeValue(value: any): void;
    /** Method that records the change on a checkbox field */
    registerOnChange(fn: (_: any) => {}): void;
    /** Method that records the touch on a checkbox field */
    registerOnTouched(fn: () => {}): void;
    /** Method that sets disabled a checkbox */
    setDisabledState(disabled: boolean): void;
    /** Focuses the checkbox. */
    focus(): void;
    /** Toggles the `checked` state of the checkbox. */
    toggle(): void;
    /**
     * Event handler for checkbox input element.
     * Toggles checked state if element is not disabled.
     */
    _onInputClick(event: Event): void;
    _onInteractionEvent(event: Event): void;
    protected _emitChangeEvent(): void;
    static ngAcceptInputType_disabled: BooleanInput;
    static ngAcceptInputType_required: BooleanInput;
}
