(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/cdk/a11y'), require('@angular/cdk/coercion'), require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('@sbb-esta/angular-core/base/checkbox', ['exports', '@angular/cdk/a11y', '@angular/cdk/coercion', '@angular/core'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global.sbbEsta = global.sbbEsta || {}, global.sbbEsta.angularCore = global.sbbEsta.angularCore || {}, global.sbbEsta.angularCore.base = global.sbbEsta.angularCore.base || {}, global.sbbEsta.angularCore.base.checkbox = {}), global.ng.cdk.a11y, global.ng.cdk.coercion, global.ng.core));
}(this, (function (exports, a11y, coercion, core) { 'use strict';

    var nextId = 0;
    /** Change event object emitted by sbb angular checkboxes. */
    var SbbCheckboxChange = /** @class */ (function () {
        function SbbCheckboxChange(
        /** The source checkbox of the event. */
        source, 
        /** The new `checked` value of the checkbox. */
        checked) {
            this.source = source;
            this.checked = checked;
        }
        return SbbCheckboxChange;
    }());
    var SbbCheckboxBase = /** @class */ (function () {
        function SbbCheckboxBase(_changeDetectorRef, _focusMonitor, elementRef, tabIndex, type) {
            var _this = this;
            if (type === void 0) { type = 'checkbox'; }
            this._changeDetectorRef = _changeDetectorRef;
            this._focusMonitor = _focusMonitor;
            /** Name value will be applied to the input element if present */
            this.name = null;
            this._checked = false;
            this._disabled = false;
            /** Event emitted when the checkbox's `checked` value changes. */
            this.change = new core.EventEmitter();
            /** Property that describes the status change of a checkbox field */
            this._onChange = function (_) { };
            /** Property that describes an updating of checkbox */
            this._onTouched = function () { };
            this._uniqueId = "sbb-" + type + "-" + ++nextId;
            this.id = this._uniqueId;
            this.tabIndex = parseInt(tabIndex, 10) || 0;
            this._focusMonitor.monitor(elementRef, true).subscribe(function (focusOrigin) {
                if (!focusOrigin) {
                    // When a focused element becomes disabled, the browser *immediately* fires a blur event.
                    // Angular does not expect events to be raised during change detection, so any state change
                    // (such as a form control's 'ng-touched') will cause a changed-after-checked error.
                    // See https://github.com/angular/angular/issues/17793. To work around this, we defer
                    // telling the form control it has been touched until the next tick.
                    Promise.resolve().then(function () {
                        _this._onTouched();
                        _changeDetectorRef.markForCheck();
                    });
                }
            });
        }
        Object.defineProperty(SbbCheckboxBase.prototype, "inputId", {
            /** Id for the inner input field. */
            get: function () {
                return (this.id || this._uniqueId) + "-input";
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SbbCheckboxBase.prototype, "required", {
            /** Whether the checkbox is required. */
            get: function () {
                return this._required;
            },
            set: function (value) {
                this._required = coercion.coerceBooleanProperty(value);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SbbCheckboxBase.prototype, "checked", {
            /** Whether the checkbox is checked. */
            get: function () {
                return this._checked;
            },
            set: function (value) {
                if (value !== this.checked) {
                    this._checked = value;
                    this._changeDetectorRef.markForCheck();
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SbbCheckboxBase.prototype, "disabled", {
            /** Whether the checkbox is disabled. */
            get: function () {
                return this._disabled;
            },
            set: function (value) {
                var newValue = coercion.coerceBooleanProperty(value);
                if (newValue !== this.disabled) {
                    this._disabled = newValue;
                    this._changeDetectorRef.markForCheck();
                }
            },
            enumerable: false,
            configurable: true
        });
        /** Sets the value in input in the checkbox field */
        SbbCheckboxBase.prototype.writeValue = function (value) {
            this.checked = !!value;
        };
        /** Method that records the change on a checkbox field */
        SbbCheckboxBase.prototype.registerOnChange = function (fn) {
            this._onChange = fn;
        };
        /** Method that records the touch on a checkbox field */
        SbbCheckboxBase.prototype.registerOnTouched = function (fn) {
            this._onTouched = fn;
        };
        /** Method that sets disabled a checkbox */
        SbbCheckboxBase.prototype.setDisabledState = function (disabled) {
            this.disabled = disabled;
        };
        /** Focuses the checkbox. */
        SbbCheckboxBase.prototype.focus = function () {
            this._focusMonitor.focusVia(this._inputElement, 'keyboard');
        };
        /** Toggles the `checked` state of the checkbox. */
        SbbCheckboxBase.prototype.toggle = function () {
            this.checked = !this.checked;
        };
        /**
         * Event handler for checkbox input element.
         * Toggles checked state if element is not disabled.
         */
        SbbCheckboxBase.prototype._onInputClick = function (event) {
            // We have to stop propagation for click events on the visual hidden input element.
            // By default, when a user clicks on a label element, a generated click event will be
            // dispatched on the associated input element. Since we are using a label element as our
            // root container, the click event on the `checkbox` will be executed twice.
            // The real click event will bubble up, and the generated click event also tries to bubble up.
            // This will lead to multiple click events.
            // Preventing bubbling for the second event will solve that issue.
            event.stopPropagation();
            if (!this.disabled) {
                this.toggle();
                // Emit our custom change event if the native input emitted one.
                // It is important to only emit it, if the native input triggered one, because
                // we don't want to trigger a change event, when the `checked` variable changes for example.
                this._emitChangeEvent();
            }
        };
        SbbCheckboxBase.prototype._onInteractionEvent = function (event) {
            // We always have to stop propagation on the change event.
            // Otherwise the change event, from the input element, will bubble up and
            // emit its event object to the `change` output.
            event.stopPropagation();
        };
        SbbCheckboxBase.prototype._emitChangeEvent = function () {
            var event = new SbbCheckboxChange(this, this.checked);
            this._onChange(this.checked);
            this.change.emit(event);
        };
        return SbbCheckboxBase;
    }());
    SbbCheckboxBase.decorators = [
        { type: core.Directive }
    ];
    SbbCheckboxBase.ctorParameters = function () { return [
        { type: core.ChangeDetectorRef },
        { type: a11y.FocusMonitor },
        { type: core.ElementRef },
        { type: String, decorators: [{ type: core.Attribute, args: ['tabindex',] }] },
        null
    ]; };
    SbbCheckboxBase.propDecorators = {
        id: [{ type: core.Input }],
        value: [{ type: core.Input }],
        ariaLabel: [{ type: core.Input, args: ['aria-label',] }],
        ariaLabelledby: [{ type: core.Input, args: ['aria-labelledby',] }],
        ariaDescribedby: [{ type: core.Input, args: ['aria-describedby',] }],
        required: [{ type: core.Input }],
        name: [{ type: core.Input }],
        checked: [{ type: core.Input }],
        disabled: [{ type: core.Input }],
        change: [{ type: core.Output }],
        _inputElement: [{ type: core.ViewChild, args: ['input',] }]
    };

    /**
     * Generated bundle index. Do not edit.
     */

    exports.SbbCheckboxBase = SbbCheckboxBase;
    exports.SbbCheckboxChange = SbbCheckboxChange;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-core-base-checkbox.umd.js.map
