(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/cdk/coercion')) :
    typeof define === 'function' && define.amd ? define('@sbb-esta/angular-core/base/processflow', ['exports', '@angular/core', '@angular/cdk/coercion'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global.sbbEsta = global.sbbEsta || {}, global.sbbEsta.angularCore = global.sbbEsta.angularCore || {}, global.sbbEsta.angularCore.base = global.sbbEsta.angularCore.base || {}, global.sbbEsta.angularCore.base.processflow = {}), global.ng.core, global.ng.cdk.coercion));
}(this, (function (exports, core, coercion) { 'use strict';

    var SbbProcessflowBase = /** @class */ (function () {
        function SbbProcessflowBase(_changeDetectorRef) {
            this._changeDetectorRef = _changeDetectorRef;
            /** Event emitted to the change of step in the process flow. */
            this.stepChange = new core.EventEmitter();
        }
        SbbProcessflowBase.prototype.ngAfterContentInit = function () {
            var _this = this;
            if (this.steps && this.steps.length) {
                Promise.resolve().then(function () {
                    _this.steps.first.active = true;
                    _this.steps.first.disabled = false;
                });
            }
        };
        SbbProcessflowBase.prototype.nextStep = function () {
            var activeStepIndex = this._findActiveStepIndex(this.steps.toArray());
            var activatedStep = false;
            if (activeStepIndex < this.steps.length - 1) {
                this.steps.forEach(function (s, i) {
                    if (i > activeStepIndex && !activatedStep) {
                        s.active = true;
                        s.disabled = false;
                        activatedStep = true;
                    }
                    else {
                        s.active = false;
                    }
                });
                this._changeDetectorRef.markForCheck();
                this.stepChange.emit(this.steps.toArray()[activeStepIndex + 1]);
            }
        };
        SbbProcessflowBase.prototype.prevStep = function () {
            var activeStepIndex = this._findActiveStepIndex(this.steps.toArray());
            if (activeStepIndex > 0) {
                this.disableStep(activeStepIndex);
                this.changeStep(activeStepIndex - 1);
            }
        };
        SbbProcessflowBase.prototype._findActiveStepIndex = function (steps) {
            return steps.findIndex(function (s) { return !!s.active; });
        };
        /**
         * Method to change on a step with a click.
         * @param $event Event generated at the click on a step.
         * @param stepIndex Index of a step.
         */
        SbbProcessflowBase.prototype.stepClick = function ($event, stepIndex) {
            $event.preventDefault();
            var currentIndex = this._findActiveStepIndex(this.steps.toArray());
            if (stepIndex < currentIndex) {
                this.changeStep(stepIndex);
            }
        };
        /**
         * Method to change a step in a process flow.
         * @param index Index of the step to change.
         */
        SbbProcessflowBase.prototype.changeStep = function (index) {
            var step = this.steps.toArray()[index];
            if (step) {
                this.steps.forEach(function (s, i) {
                    s.active = false;
                    if (i > index) {
                        s.disabled = true;
                    }
                });
                step.active = true;
                this._changeDetectorRef.markForCheck();
                this.stepChange.emit(step.descriptor);
            }
        };
        /** Method to disable a step in a process flow.
         * @param index Index of the step to disable.
         */
        SbbProcessflowBase.prototype.disableStep = function (index) {
            var step = this.steps.toArray()[index];
            if (step) {
                step.disabled = true;
                this._changeDetectorRef.markForCheck();
            }
        };
        SbbProcessflowBase.prototype.reset = function () {
            this.steps.forEach(function (s) {
                s.active = false;
                s.disabled = true;
            });
            this.ngAfterContentInit();
            this._changeDetectorRef.markForCheck();
        };
        SbbProcessflowBase.prototype.getActiveStep = function () {
            if (this.steps && this.steps.length) {
                var activeStepIndex = this._findActiveStepIndex(this.steps.toArray());
                if (activeStepIndex > -1) {
                    return this.steps.toArray()[activeStepIndex];
                }
            }
            return null;
        };
        return SbbProcessflowBase;
    }());
    SbbProcessflowBase.decorators = [
        { type: core.Directive }
    ];
    SbbProcessflowBase.ctorParameters = function () { return [
        { type: core.ChangeDetectorRef }
    ]; };
    SbbProcessflowBase.propDecorators = {
        stepChange: [{ type: core.Output }]
    };

    var SbbProcessflowStepDescriptor = /** @class */ (function () {
        function SbbProcessflowStepDescriptor() {
            /** Refers to the active status of a step in a process flow. */
            this.active = false;
            /** Refers to the disable status of a step in a process flow.  */
            this.disabled = true;
        }
        return SbbProcessflowStepDescriptor;
    }());
    var SbbProcessflowStepBase = /** @class */ (function () {
        function SbbProcessflowStepBase(_changeDetectorRef) {
            this._changeDetectorRef = _changeDetectorRef;
            /** Refers to the processFlowStep istance. */
            this.descriptor = new SbbProcessflowStepDescriptor();
        }
        Object.defineProperty(SbbProcessflowStepBase.prototype, "title", {
            get: function () {
                return this.descriptor.title;
            },
            /** Title of a step in a process flow. */
            set: function (value) {
                this.descriptor.title = value;
                this._changeDetectorRef.markForCheck();
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SbbProcessflowStepBase.prototype, "active", {
            get: function () {
                return this.descriptor.active;
            },
            /** Refers to the active status of a step in a process flow.  */
            set: function (value) {
                this.descriptor.active = coercion.coerceBooleanProperty(value);
                this._changeDetectorRef.markForCheck();
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SbbProcessflowStepBase.prototype, "disabled", {
            get: function () {
                return this.descriptor.disabled;
            },
            /** Refers to the disable status of a step in a process flow.  */
            set: function (value) {
                this.descriptor.disabled = coercion.coerceBooleanProperty(value);
                this._changeDetectorRef.markForCheck();
            },
            enumerable: false,
            configurable: true
        });
        return SbbProcessflowStepBase;
    }());
    SbbProcessflowStepBase.decorators = [
        { type: core.Directive }
    ];
    SbbProcessflowStepBase.ctorParameters = function () { return [
        { type: core.ChangeDetectorRef }
    ]; };
    SbbProcessflowStepBase.propDecorators = {
        title: [{ type: core.Input }],
        active: [{ type: core.Input }],
        disabled: [{ type: core.Input }]
    };

    /**
     * Generated bundle index. Do not edit.
     */

    exports.SbbProcessflowBase = SbbProcessflowBase;
    exports.SbbProcessflowStepBase = SbbProcessflowStepBase;
    exports.SbbProcessflowStepDescriptor = SbbProcessflowStepDescriptor;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-core-base-processflow.umd.js.map
