(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('@sbb-esta/angular-core/datetime', ['exports', '@angular/core', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global.sbbEsta = global.sbbEsta || {}, global.sbbEsta.angularCore = global.sbbEsta.angularCore || {}, global.sbbEsta.angularCore.datetime = {}), global.ng.core, global.ng.common));
}(this, (function (exports, core, common) { 'use strict';

    /** Adapts type `D` to be usable as a date by cdk-based components that work with dates. */
    var SbbDateAdapter = /** @class */ (function () {
        function SbbDateAdapter() {
        }
        /**
         * Attempts to deserialize a value to a valid date object. This is different from parsing in that
         * deserialize should only accept non-ambiguous, locale-independent formats (e.g. a ISO 8601
         * string). The default implementation does not allow any deserialization, it simply checks that
         * the given value is already a valid date object or null. The `<sbb-datepicker>` will call this
         * method on all of it's `@Input()` properties that accept dates. It is therefore possible to
         * support passing values from your backend directly to these properties by overriding this method
         * to also deserialize the format used by your backend.
         * @param value The value to be deserialized into a date object.
         * @returns The deserialized date object, either a valid date, null if the value can be
         *     deserialized into a null date (e.g. the empty string), or an invalid date.
         */
        SbbDateAdapter.prototype.deserialize = function (value) {
            if (value == null || (this.isDateInstance(value) && this.isValid(value))) {
                return value;
            }
            return this.invalid();
        };
        /**
         * Sets the locale used for all dates.
         * @param locale The new locale.
         */
        SbbDateAdapter.prototype.setLocale = function (locale) {
            this._locale = locale;
        };
        /**
         * Compares two dates.
         * @param first The first date to compare.
         * @param second The second date to compare.
         * @returns 0 if the dates are equal, a number less than 0 if the first date is earlier,
         *     a number greater than 0 if the first date is later.
         */
        SbbDateAdapter.prototype.compareDate = function (first, second) {
            return (this.getYear(first) - this.getYear(second) ||
                this.getMonth(first) - this.getMonth(second) ||
                this.getDate(first) - this.getDate(second));
        };
        /**
         * Checks if two dates are equal.
         * @param first The first date to check.
         * @param second The second date to check.
         * @returns Whether the two dates are equal.
         *     Null dates are considered equal to other null dates.
         */
        SbbDateAdapter.prototype.sameDate = function (first, second) {
            if (first && second) {
                var firstValid = this.isValid(first);
                var secondValid = this.isValid(second);
                if (firstValid && secondValid) {
                    return !this.compareDate(first, second);
                }
                return firstValid === secondValid;
            }
            return first === second;
        };
        /**
         * Clamp the given date between min and max dates.
         * @param date The date to clamp.
         * @param min The minimum value to allow. If null or omitted no min is enforced.
         * @param max The maximum value to allow. If null or omitted no max is enforced.
         * @returns `min` if `date` is less than `min`, `max` if date is greater than `max`,
         *     otherwise `date`.
         */
        SbbDateAdapter.prototype.clampDate = function (date, min, max) {
            if (min && this.compareDate(date, min) < 0) {
                return min;
            }
            if (max && this.compareDate(date, max) > 0) {
                return max;
            }
            return date;
        };
        return SbbDateAdapter;
    }());

    var SBB_DATE_FORMATS = new core.InjectionToken('sbb-date-formats');

    var SBB_DATE_PIPE_DATE_FORMATS = {
        dateInput: 'EEEEEE, dd.MM.yyyy',
        dateA11yLabel: 'dd MM yyyy',
    };

    var SBB_DATEPICKER_2DIGIT_YEAR_PIVOT = new core.InjectionToken('SBB_DATEPICKER_2DIGIT_YEAR_PIVOT');

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from, pack) {
        if (pack || arguments.length === 2)
            for (var i = 0, l = from.length, ar; i < l; i++) {
                if (ar || !(i in from)) {
                    if (!ar)
                        ar = Array.prototype.slice.call(from, 0, i);
                    ar[i] = from[i];
                }
            }
        return to.concat(ar || from);
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    }
    function __classPrivateFieldSet(receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    }

    /**
     * Matches strings that have the form of a valid RFC 3339 string
     * (https://tools.ietf.org/html/rfc3339). Note that the string may not actually be a valid date
     * because the regex will match strings an with out of bounds month, date, etc.
     */
    var ISO_8601_REGEX = /^\d{4}-\d{2}-\d{2}(?:T\d{2}:\d{2}:\d{2}(?:\.\d+)?(?:Z|(?:(?:\+|-)\d{2}:\d{2}))?)?$/;
    /** Creates an array and fills it with values. */
    function range(length, valueFunction) {
        var valuesArray = Array(length);
        for (var i = 0; i < length; i++) {
            valuesArray[i] = valueFunction(i);
        }
        return valuesArray;
    }
    var SbbNativeDateAdapter = /** @class */ (function (_super) {
        __extends(SbbNativeDateAdapter, _super);
        function SbbNativeDateAdapter(_locale, yearPivot) {
            var _this = _super.call(this) || this;
            _this._locale = _locale;
            _this._titleCasePipe = new common.TitleCasePipe();
            _this._datePipe = new common.DatePipe(_locale);
            _this._yearPivot = typeof yearPivot === 'number' ? yearPivot : new Date().getFullYear() - 1975;
            return _this;
        }
        SbbNativeDateAdapter.prototype.getYear = function (date) {
            return date.getFullYear();
        };
        SbbNativeDateAdapter.prototype.getMonth = function (date) {
            return date.getMonth();
        };
        SbbNativeDateAdapter.prototype.getDate = function (date) {
            return date.getDate();
        };
        SbbNativeDateAdapter.prototype.getDayOfWeek = function (date) {
            return date.getDay();
        };
        SbbNativeDateAdapter.prototype.getMonthName = function (date) {
            return this._datePipe.transform(date, 'LLLL');
        };
        SbbNativeDateAdapter.prototype.getMonthNames = function (style) {
            var _this = this;
            var format;
            switch (style) {
                case 'long':
                    format = 'LLLL';
                    break;
                case 'narrow':
                    format = 'LLLLL';
                    break;
                default:
                    format = 'LLL';
                    break;
            }
            return range(12, function (i) { return _this._datePipe.transform(new Date(2017, i, 1), format); });
        };
        SbbNativeDateAdapter.prototype.getDateNames = function () {
            var _this = this;
            return range(31, function (i) { return _this._datePipe.transform(new Date(2017, 0, i + 1), 'd'); });
        };
        SbbNativeDateAdapter.prototype.getDayOfWeekNames = function (style) {
            var _this = this;
            var format;
            switch (style) {
                case 'long':
                    format = 'EEEE';
                    break;
                case 'narrow':
                    format = 'EEEEE';
                    break;
                default:
                    format = 'EEE';
                    break;
            }
            return range(7, function (i) { return _this._datePipe.transform(new Date(2017, 0, i + 1), format); });
        };
        SbbNativeDateAdapter.prototype.getYearName = function (date) {
            return this._datePipe.transform(date, 'yyyy');
        };
        SbbNativeDateAdapter.prototype.getFirstDayOfWeek = function () {
            return 1;
        };
        SbbNativeDateAdapter.prototype.getNumDaysInMonth = function (date) {
            var lastDayOfMonth = new Date(0);
            lastDayOfMonth.setFullYear(date.getFullYear(), date.getMonth() + 1, 0);
            lastDayOfMonth.setHours(0, 0, 0, 0);
            return lastDayOfMonth.getDate();
        };
        SbbNativeDateAdapter.prototype.clone = function (date) {
            return new Date(date.valueOf());
        };
        SbbNativeDateAdapter.prototype.createDate = function (year, month, date) {
            // Check for invalid month and date (except upper bound on date which we have to check after
            // creating the Date).
            if (month < 0 || month > 11) {
                throw Error("Invalid month index \"" + month + "\". Month index has to be between 0 and 11.");
            }
            if (date < 1) {
                throw Error("Invalid date \"" + date + "\". Date has to be greater than 0.");
            }
            var result = this._createDateWithOverflow(year, month, date);
            // Check that the date wasn't above the upper bound for the month, causing the month to overflow
            if (result.getMonth() !== month) {
                throw Error("Invalid date \"" + date + "\" for month with index \"" + month + "\".");
            }
            return result;
        };
        SbbNativeDateAdapter.prototype.today = function () {
            var date = new Date();
            date.setHours(0, 0, 0, 0);
            return date;
        };
        SbbNativeDateAdapter.prototype.parse = function (value) {
            if (typeof value === 'number') {
                return new Date(value);
            }
            else if (typeof value === 'string') {
                return this._parseStringDate(value);
            }
            return null;
        };
        SbbNativeDateAdapter.prototype.format = function (date, displayFormat) {
            if (!this.isValid(date)) {
                throw Error('NativeDateAdapter: Cannot format invalid date.');
            }
            return this._titleCasePipe.transform(this._datePipe.transform(date, displayFormat));
        };
        SbbNativeDateAdapter.prototype.addCalendarYears = function (date, years) {
            return this.addCalendarMonths(date, years * 12);
        };
        SbbNativeDateAdapter.prototype.addCalendarMonths = function (date, months) {
            var targetMonth = date.getMonth() + months;
            var dateWithCorrectMonth = new Date(0);
            dateWithCorrectMonth.setFullYear(date.getFullYear(), targetMonth, 1);
            dateWithCorrectMonth.setHours(0, 0, 0, 0);
            var daysInMonth = this.getNumDaysInMonth(dateWithCorrectMonth);
            var newDate = this.clone(date);
            // Adapt last day of month for shorter months
            newDate.setMonth(targetMonth, Math.min(daysInMonth, date.getDate()));
            return newDate;
        };
        SbbNativeDateAdapter.prototype.addCalendarDays = function (date, days) {
            var newDate = this.clone(date);
            newDate.setDate(newDate.getDate() + days);
            return newDate;
        };
        SbbNativeDateAdapter.prototype.toIso8601 = function (date) {
            return this._datePipe.transform(date, 'yyyy-MM-dd');
        };
        /**
         * Returns the given value if given a valid Date or null. Deserializes valid ISO 8601 strings
         * (https://www.ietf.org/rfc/rfc3339.txt) into valid Dates and empty string into null. Returns an
         * invalid date for all other values.
         */
        SbbNativeDateAdapter.prototype.deserialize = function (value) {
            if (typeof value === 'string') {
                if (!value) {
                    return null;
                }
                // The `Date` constructor accepts formats other than ISO 8601, so we need to make sure the
                // string is the right format first.
                if (ISO_8601_REGEX.test(value)) {
                    var date = new Date(value);
                    if (this.isValid(date)) {
                        return date;
                    }
                }
            }
            return _super.prototype.deserialize.call(this, value);
        };
        SbbNativeDateAdapter.prototype.isDateInstance = function (obj) {
            return obj instanceof Date;
        };
        SbbNativeDateAdapter.prototype.isValid = function (date) {
            return !isNaN(date.valueOf());
        };
        SbbNativeDateAdapter.prototype.invalid = function () {
            return new Date(NaN);
        };
        SbbNativeDateAdapter.prototype._parseStringDate = function (value) {
            var match = /^(\w+,[ ]?)?(\d+)\.(\d+)\.(\d+)$/.exec(value);
            if (!match) {
                return null;
            }
            var date = this._createDateWithOverflow(+match[4], +match[3] - 1, +match[2]);
            return this._normalizeYear(date);
        };
        SbbNativeDateAdapter.prototype._normalizeYear = function (date) {
            if (date.getFullYear() < 0 || date.getFullYear() >= 100) {
                return date;
            }
            var yearOffset = date.getFullYear() <= this._yearPivot ? 2000 : 1900;
            return new Date(date.getFullYear() + yearOffset, date.getMonth(), date.getDate());
        };
        /** Creates a date but allows the month and date to overflow. */
        SbbNativeDateAdapter.prototype._createDateWithOverflow = function (year, month, date) {
            var result = new Date(year, month, date);
            // We need to correct for the fact that JS native Date treats years in range [0, 99] as
            // abbreviations for 19xx.
            if (year >= 0 && year < 100) {
                result.setFullYear(this.getYear(result) - 1900);
            }
            return result;
        };
        return SbbNativeDateAdapter;
    }(SbbDateAdapter));
    SbbNativeDateAdapter.decorators = [
        { type: core.Injectable }
    ];
    SbbNativeDateAdapter.ctorParameters = function () { return [
        { type: String, decorators: [{ type: core.Inject, args: [core.LOCALE_ID,] }] },
        { type: Number, decorators: [{ type: core.Optional }, { type: core.Inject, args: [SBB_DATEPICKER_2DIGIT_YEAR_PIVOT,] }] }
    ]; };

    var SbbBusinessDateAdapter = /** @class */ (function (_super) {
        __extends(SbbBusinessDateAdapter, _super);
        function SbbBusinessDateAdapter(_locale, yearPivot) {
            var _this = _super.call(this, _locale, yearPivot) || this;
            _this._locale = _locale;
            return _this;
        }
        SbbBusinessDateAdapter.prototype._parseStringDate = function (value) {
            return _super.prototype._parseStringDate.call(this, value) || this._parseStringDateBusiness(value);
        };
        SbbBusinessDateAdapter.prototype._parseStringDateBusiness = function (value) {
            var match = /^(\w+,[ ]?)?(\d{2})(\d{2})(\d{2}|\d{4})$/.exec(value);
            if (!match) {
                return null;
            }
            return this._normalizeYear(this._createDateWithOverflow(+match[4], +match[3] - 1, +match[2]));
        };
        return SbbBusinessDateAdapter;
    }(SbbNativeDateAdapter));
    SbbBusinessDateAdapter.decorators = [
        { type: core.Injectable }
    ];
    SbbBusinessDateAdapter.ctorParameters = function () { return [
        { type: String, decorators: [{ type: core.Inject, args: [core.LOCALE_ID,] }] },
        { type: Number, decorators: [{ type: core.Optional }, { type: core.Inject, args: [SBB_DATEPICKER_2DIGIT_YEAR_PIVOT,] }] }
    ]; };

    var SBB_BUSINESS_DATE_ADAPTER = {
        provide: SbbDateAdapter,
        useClass: SbbBusinessDateAdapter,
    };

    /**
     * Generated bundle index. Do not edit.
     */

    exports.SBB_BUSINESS_DATE_ADAPTER = SBB_BUSINESS_DATE_ADAPTER;
    exports.SBB_DATEPICKER_2DIGIT_YEAR_PIVOT = SBB_DATEPICKER_2DIGIT_YEAR_PIVOT;
    exports.SBB_DATE_FORMATS = SBB_DATE_FORMATS;
    exports.SBB_DATE_PIPE_DATE_FORMATS = SBB_DATE_PIPE_DATE_FORMATS;
    exports.SbbBusinessDateAdapter = SbbBusinessDateAdapter;
    exports.SbbDateAdapter = SbbDateAdapter;
    exports.SbbNativeDateAdapter = SbbNativeDateAdapter;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-core-datetime.umd.js.map
