/** The issuer URL for SBB SSO production environment. */
const SBB_SSO_ISSUER_URL = 'https://sso.sbb.ch/auth/realms/SBB_Public';
/**
 * DO NOT USE THIS FOR PRODUCTION.
 * The issuer URL for SBB SSO integration environment.
 */
const SBB_SSO_INT_ISSUER_URL = 'https://sso-int.sbb.ch/auth/realms/SBB_Public';
/** The IDP hint for SBB SSO for Swisspass production environment. */
const SBB_SSO_IDP_AZURE_AD = 'azure_sbb_prod';
/**
 * DO NOT USE THIS FOR PRODUCTION.
 * The IDP hint for SBB SSO for Swisspass integration environment.
 */
const SBB_SSO_IDP_AZURE_AD_TEST = 'azure_sbb_test';
/** The IDP hint for SBB SSO for Swisspass production environment. */
const SBB_SSO_IDP_SWISSPASS = 'swisspass_prod';
/**
 * DO NOT USE THIS FOR PRODUCTION.
 * The IDP hint for SBB SSO for Swisspass integration environment.
 */
const SBB_SSO_IDP_SWISSPASS_INT = 'swisspass_int';
/**
 * DO NOT USE THIS FOR PRODUCTION.
 * The IDP hint for SBB SSO for Swisspass test environment.
 */
const SBB_SSO_IDP_SWISSPASS_TEST = 'swisspass_test';
/** The IDP hint for SBB SSO for Google. */
const SBB_SSO_IDP_GOOGLE = 'google';
/** The IDP hint for SBB SSO for Microsoft. */
const SBB_SSO_IDP_MICROSOFT = 'microsoft';
/** The IDP hint for SBB SSO for GitHub. */
const SBB_SSO_IDP_GITHUB = 'github';
/**
 * IDP hint for SBB Azure AD.
 * Can be used for the customQueryParams configuration for angular-oauth2-oidc.
 */
const SBB_SSO_IDP_HINT_AZURE_AD = { kc_idp_hint: SBB_SSO_IDP_AZURE_AD };

const ɵ0 = (s) => Buffer.from(s, 'base64').toString('binary');
const base64Decode = typeof atob === 'function' ? atob : ɵ0;
/**
 * Retrieve the resource access information from the access token from SBB SSO.
 * This can either be used by directly providing the access token as a string
 * or by providing the OAuthService from angular-oauth2-oidc.
 */
function resourceAccess(accessToken) {
    accessToken =
        !accessToken || typeof accessToken === 'string' ? accessToken : accessToken.getAccessToken();
    if (!accessToken || typeof accessToken !== 'string') {
        return null;
    }
    const payload = base64Decode(accessToken.split('.')[1]);
    const parsedAccessToken = JSON.parse(payload);
    if (!('resource_access' in parsedAccessToken) || !parsedAccessToken.resource_access) {
        return null;
    }
    return parsedAccessToken.resource_access;
}

/**
 * Generated bundle index. Do not edit.
 */

export { SBB_SSO_IDP_AZURE_AD, SBB_SSO_IDP_AZURE_AD_TEST, SBB_SSO_IDP_GITHUB, SBB_SSO_IDP_GOOGLE, SBB_SSO_IDP_HINT_AZURE_AD, SBB_SSO_IDP_MICROSOFT, SBB_SSO_IDP_SWISSPASS, SBB_SSO_IDP_SWISSPASS_INT, SBB_SSO_IDP_SWISSPASS_TEST, SBB_SSO_INT_ISSUER_URL, SBB_SSO_ISSUER_URL, resourceAccess };
//# sourceMappingURL=oauth.js.map
